UniqueDeviceIdentifierPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • UniqueDeviceIdentifierPlatform
Implementers

Constructors

UniqueDeviceIdentifierPlatform()
Constructs a UniqueDeviceIdentifierPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUniqueIdentifier() → Future<String?>
Returns the unique device identifier for the current platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ UniqueDeviceIdentifierPlatform
The default instance of UniqueDeviceIdentifierPlatform to use.
getter/setter pair