Navigator class

Available extensions
Annotations

Constructors

Properties

deviceMemory → JSAny?

Available on Navigator, provided by the NavigatorExtension extension

no setter
hardwareConcurrency → int

Available on Navigator, provided by the NavigatorExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
languages → JSArray<JSAny?>

Available on Navigator, provided by the NavigatorExtension extension

no setter
maxTouchPoints → int

Available on Navigator, provided by the NavigatorExtension extension

no setter
platform → String

Available on Navigator, provided by the NavigatorExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String

Available on Navigator, provided by the NavigatorExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited